@@ -4,14 +4,18 @@ mypythontools
 
 Some tools/functions/snippets used across projects.
 
+Official documentation - https://mypythontools.readthedocs.io/
+Official repo - https://github.com/Malachov/mypythontools
+
 Usually used from IDE. Used paths are infered and things like building the
-application with pyinstaller incrementing version, pushing to github or deploying
-to Pypi is matter of calling one function, or clicking one button (e.g. Vs code task).
+application with pyinstaller incrementing version, generating rst files for sphinx docs,
+pushing to github or deploying to Pypi is matter of calling one function
+or clicking one button (e.g. Vs code task).
 
 Many projects - one codebase.
 
 If you are not sure whether structure of app that will work with this code, there is python starter repo
-on [github](https://github.com/Malachov/my-python-starter)
+on https://github.com/Malachov/my-python-starter
 
 Paths are infered, but if you have atypical structure or have more projects in cwd, use `mypythontools.misc.set_paths()`.
 """
@@ -22,7 +26,7 @@ from . import deploy
 from . import misc
 from . import pyvueeel
 
-__version__ = "0.0.26"
+__version__ = "0.0.27"
 
 __author__ = "Daniel Malachov"
 __license__ = "MIT"
